hf_ez_fill_mask_local_inference: Fill Mask Local Inference

View source: R/ez.R

hf_ez_fill_mask_local_inferenceR Documentation

Fill Mask Local Inference

Description

Fill Mask Local Inference

Usage

hf_ez_fill_mask_local_inference(string, tidy = TRUE, ...)

Arguments

string

a string to be filled from, must contain the [MASK] token (check model card for exact name of the mask)

tidy

Whether to tidy the results into a tibble. Default: TRUE (tidy the results)

...

Additional arguments passed internally, including the model object or model ID.

Value

The results of the inference

See Also

https://huggingface.co/docs/transformers/main/en/pipeline_tutorial


huggingfaceR documentation built on Aug. 30, 2026, 1:06 a.m.