hf_ez_text2text_generation_local_inference: Text2Text Generation Local Inference

View source: R/ez.R

hf_ez_text2text_generation_local_inferenceR Documentation

Text2Text Generation Local Inference

Description

Text2Text Generation Local Inference

Usage

hf_ez_text2text_generation_local_inference(string, tidy = TRUE, ...)

Arguments

string

a general request for the model to perform or answer

tidy

Whether to tidy the results into a tibble. Default: TRUE (tidy the results)

...

Additional arguments passed internally, including the model object or model ID.

Value

The results of the inference

See Also

https://huggingface.co/docs/transformers/main/en/pipeline_tutorial


huggingfaceR documentation built on Aug. 30, 2026, 1:06 a.m.