hf_fill_mask_payload: Fill Mask Task Payload

View source: R/inference.R

hf_fill_mask_payloadR Documentation

Fill Mask Task Payload

Description

Tries to fill in a hole with a missing word (token to be precise). That’s the base task for BERT models.

Usage

hf_fill_mask_payload(string)

Arguments

string

a string to be filled from, must contain the [MASK] token (check model card for exact name of the mask)

Value

An inference payload

See Also

https://huggingface.co/docs/api-inference/detailed_parameters#fill-mask-task

Examples

hf_fill_mask_payload("The capital of France is [MASK].")

huggingfaceR documentation built on Aug. 30, 2026, 1:06 a.m.