hf_table_question_answering_payload: Table Question Answering Payload

View source: R/inference.R

hf_table_question_answering_payloadR Documentation

Table Question Answering Payload

Description

Don’t know SQL? Don’t want to dive into a large spreadsheet? Ask questions in plain english!

Usage

hf_table_question_answering_payload(query, table)

Arguments

query

The query in plain text that you want to ask the table

table

A table of data represented as a dict of list where entries are headers and the lists are all the values, all lists must have the same size.

Value

An inference payload

See Also

https://huggingface.co/docs/api-inference/detailed_parameters#table-question-answering-task

Examples

hf_table_question_answering_payload(
  query = "How many rows are shown?",
  table = list(name = c("Alice", "Bob"), rows = c("1", "2"))
)

huggingfaceR documentation built on Aug. 30, 2026, 1:06 a.m.