hf_text2text_generation_payload: Text2Text Generation Payload

View source: R/inference.R

hf_text2text_generation_payloadR Documentation

Text2Text Generation Payload

Description

takes an input containing the sentence including the task and returns the output of the accomplished task.

Usage

hf_text2text_generation_payload(string)

Arguments

string

a string containing a question or task and a sentence from which the answer is derived

Value

An inference payload

See Also

https://huggingface.co/docs/api-inference/detailed_parameters#text2text-generation-task

Examples

hf_text2text_generation_payload("translate English to French: Hello")

huggingfaceR documentation built on Aug. 30, 2026, 1:06 a.m.