Skip to contents

This task is well known to translate text from one language to another

Usage

hf_translation_payload(string)

Arguments

string

a string to be translated in the original languages

Value

An inference payload

Examples

hf_translation_payload("Hello, world.")
#> $inputs
#> [1] "Hello, world."
#>