| hf_clear_provider_cache | R Documentation |
‘huggingfaceR' caches each model’s Hugging Face provider mapping for the duration of the R session so that repeated inference calls do not re-query the Hub. Call this function to discard the cache after provider availability changes, or in tests.
hf_clear_provider_cache()
'NULL', invisibly.
hf_clear_provider_cache()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.