Calculate the semantic similarity between one text and a list of other sentences by comparing their embeddings.
Examples
hf_sentence_similarity_payload(
source_sentence = "A happy person",
sentences = list("A joyful person", "A rainy day")
)
#> $inputs
#> $inputs$source_sentence
#> [1] "A happy person"
#>
#> $inputs$sentences
#> $inputs$sentences[[1]]
#> [1] "A joyful person"
#>
#> $inputs$sentences[[2]]
#> [1] "A rainy day"
#>
#>
#>
#> $task
#> [1] "sentence-similarity"
#>