takes an input containing the sentence including the task and returns the output of the accomplished task.
Usage
hf_text2text_generation_payload(string)
Arguments
- string
a string containing a question or task and a sentence from which the answer is derived
Value
An inference payload
Examples
hf_text2text_generation_payload("translate English to French: Hello")
#> $inputs
#> [1] "translate English to French: Hello"
#>